TypeObjectBuilder

Struct TypeObjectBuilder 

pub struct TypeObjectBuilder;
Einstiegspunkt.

Implementations

Source

impl TypeObjectBuilder

pub fn struct_type(name: impl Into<String>) -> StructBuilder

Starts a struct builder with the given qualified name (e.g. “::sensors::Chatter”).

pub fn enum_type(name: impl Into<String>) -> EnumBuilder

Starts an enum builder.

pub fn alias(name: impl Into<String>, target: TypeIdentifier) -> AliasBuilder

Starts an alias builder.

Source

impl TypeObjectBuilder

pub fn union_type( name: impl Into<String>, discriminator_type: TypeIdentifier, ) -> UnionBuilder

Starts a union builder. discriminator_type is typically an enum or an integer primitive.

pub fn sequence(element: TypeIdentifier, bound: u32) -> SequenceBuilder

Starts a sequence builder. bound=0 = unbounded.

pub fn array(element: TypeIdentifier, dimensions: Vec<u32>) -> ArrayBuilder

Starts an array builder with the given list of dimensions.

pub fn map(key: TypeIdentifier, value: TypeIdentifier, bound: u32) -> MapBuilder

Starts a map builder.

pub fn bitmask(name: impl Into<String>) -> BitmaskBuilder

Starts a bitmask builder.

pub fn bitset(name: impl Into<String>) -> BitsetBuilder

Starts a bitset builder.