pub enum TypeMatchResult {
Matches,
Incompatible {
reason: &'static str,
},
}Expand description
Result of a type match. Identical in semantics to Assignable,
but a standalone type for the matcher API (so the
call site is not coupled to the internal Assignable).
Variants
Matches
Writer type and reader type are compatible for a match.
Incompatible
Incompatible — static reason.
Implementations