pub struct TypeObjectBuilder;Expand description
Einstiegspunkt.
Implementations
Sourceimpl TypeObjectBuilder
impl TypeObjectBuilder
Sourcepub fn struct_type(name: impl Into<String>) -> StructBuilder
pub fn struct_type(name: impl Into<String>) -> StructBuilder
Starts a struct builder with the given qualified name (e.g. “::sensors::Chatter”).
Sourcepub fn enum_type(name: impl Into<String>) -> EnumBuilder
pub fn enum_type(name: impl Into<String>) -> EnumBuilder
Starts an enum builder.
Sourcepub fn alias(name: impl Into<String>, target: TypeIdentifier) -> AliasBuilder
pub fn alias(name: impl Into<String>, target: TypeIdentifier) -> AliasBuilder
Starts an alias builder.
Sourceimpl TypeObjectBuilder
impl TypeObjectBuilder
Sourcepub fn union_type(
name: impl Into<String>,
discriminator_type: TypeIdentifier,
) -> UnionBuilder
pub fn union_type( name: impl Into<String>, discriminator_type: TypeIdentifier, ) -> UnionBuilder
Starts a union builder. discriminator_type is typically
an enum or an integer primitive.
Sourcepub fn sequence(element: TypeIdentifier, bound: u32) -> SequenceBuilder
pub fn sequence(element: TypeIdentifier, bound: u32) -> SequenceBuilder
Starts a sequence builder. bound=0 = unbounded.
Sourcepub fn array(element: TypeIdentifier, dimensions: Vec<u32>) -> ArrayBuilder
pub fn array(element: TypeIdentifier, dimensions: Vec<u32>) -> ArrayBuilder
Starts an array builder with the given list of dimensions.
Sourcepub fn map(key: TypeIdentifier, value: TypeIdentifier, bound: u32) -> MapBuilder
pub fn map(key: TypeIdentifier, value: TypeIdentifier, bound: u32) -> MapBuilder
Starts a map builder.
Sourcepub fn bitmask(name: impl Into<String>) -> BitmaskBuilder
pub fn bitmask(name: impl Into<String>) -> BitmaskBuilder
Starts a bitmask builder.
Sourcepub fn bitset(name: impl Into<String>) -> BitsetBuilder
pub fn bitset(name: impl Into<String>) -> BitsetBuilder
Starts a bitset builder.